@@ -1,4 +1,4 @@
-# $Id: coarseR.R, v1.2.3 2015/08/05 12:00:00 hsbadr EPS JHU               #
+# $Id: coarseR.R, v2.1.1 2019/01/02 12:00:00 hsbadr EPS JHU               #
 #-------------------------------------------------------------------------#
 # This function is a part of HiClimR R package.                           #
 #-------------------------------------------------------------------------#
@@ -37,52 +37,65 @@
 #   1.2.2   |  07/21/15  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
 #   1.2.3   |  08/05/15  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
 #-------------------------------------------------------------------------#
-# COPYRIGHT(C) 2013-2015 Earth and Planetary Sciences (EPS), JHU.         #
+#   2.0.0   |  12/22/18  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   2.1.0   |  01/01/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#   2.1.1   |  01/02/19  |  Updated   |  Hamada S. Badr  |  badr@jhu.edu  #
+#-------------------------------------------------------------------------#
+# COPYRIGHT(C) 2013-2019 Earth and Planetary Sciences (EPS), JHU.         #
 #-------------------------------------------------------------------------#
 # Function: Coarsening spatial resolution for gridded data                #
 #-------------------------------------------------------------------------#
 
-coarseR <- function(x = x, lon = lon, lat = lat, lonStep = 1, latStep = 1, verbose = TRUE) {
-
+coarseR <-
+  function(x = x,
+           lon = lon,
+           lat = lat,
+           lonStep = 1,
+           latStep = 1,
+           verbose = TRUE) {
     xc <- list()
     xc$lon <- lon
     xc$lat <- lat
     xc$x <- x
     
     if (!is.null(lon) && !is.null(lat)) {
-        if (as.numeric(dim(x)[1]) == as.numeric(length(unique(lon)) * length(unique(lat)))) {
-            lon0 <- unique(lon)
-            lat0 <- unique(lat)
-            xGrid <- grid2D(lon0, lat0)
-            
-            rownames(x) <- paste(c(xGrid$lon), c(xGrid$lat), sep = ",")
-            
-            lon1 <- lon0[seq(1, length(lon0), by = lonStep)]
-            lat1 <- lat0[seq(1, length(lat0), by = latStep)]
-            
-            xc$lon <- c(grid2D(lon1, lat1)$lon)
-            xc$lat <- c(grid2D(lon1, lat1)$lat)
-            
-            if (lonStep > 1 || latStep > 1) {
-                xc$x <- x[which(rownames(x) %in% paste(xc$lon, xc$lat, 
-                  sep = ",")), ]
-                
-                # Return the original row numbers
-                rownumbers <- 1:nrow(x)
-                xc$rownum <- rownumbers[which(rownames(x) %in% paste(xc$lon, xc$lat, 
-                  sep = ","))]
-            }
-        } else {
-            if (lonStep > 1 || latStep > 1) {
-                if (verbose) write("---> WARNING: ungridded data is not supported for coarsening!", 
-                  "")
-            }
+      if (as.numeric(dim(x)[1]) == as.numeric(length(unique(lon)) * length(unique(lat)))) {
+        lon0 <- unique(lon)
+        lat0 <- unique(lat)
+        xGrid <- grid2D(lon0, lat0)
+        
+        rownames(x) <-
+          paste(c(xGrid$lon), c(xGrid$lat), sep = ",")
+        
+        lon1 <- lon0[seq(1, length(lon0), by = lonStep)]
+        lat1 <- lat0[seq(1, length(lat0), by = latStep)]
+        
+        xc$lon <- c(grid2D(lon1, lat1)$lon)
+        xc$lat <- c(grid2D(lon1, lat1)$lat)
+        
+        if (lonStep > 1 || latStep > 1) {
+          xc$x <- x[which(rownames(x) %in% paste(xc$lon, xc$lat,
+                                                 sep = ",")),]
+          
+          # Return the original row numbers
+          rownumbers <- 1:nrow(x)
+          xc$rownum <-
+            rownumbers[which(rownames(x) %in% paste(xc$lon, xc$lat,
+                                                    sep = ","))]
         }
+      } else {
+        if (lonStep > 1 || latStep > 1) {
+          if (verbose)
+            write("---> WARNING: ungridded data is not supported for coarsening!",
+                  "")
+        }
+      }
     } else {
-        if (verbose) write("---> WARNING: valid longitude and latitude vectors are not provided!", 
-            "")
+      if (verbose)
+        write("---> WARNING: valid longitude and latitude vectors are not provided!",
+              "")
     }
-
+    
     #gc()
     return(xc)
-}
+  }
